%define nginx_user   		nginx
%define nginx_group 		%{nginx_user}
%define nginx_home      	%{_localstatedir}/lib/nginx
%define nginx_home_tmp  	%{nginx_home}/tmp
%define nginx_logdir    	%{_localstatedir}/log/nginx
%define nginx_confdir   	%{_sysconfdir}/nginx
%define nginx_datadir   	%{_datadir}/nginx
%define nginx_webroot   	%{nginx_datadir}/html


%define rtmp_ext                nginx-rtmp-module
%define rtmp_ext_version        1.1.5
%define rtmp                    %{rtmp_ext}-%{rtmp_ext_version}
%define rtmp_nover              %{rtmp_ext}
%define with_rtmp_ext           1
%define	sticky_module_version	1.1


%define openssl_version		1.0.1j
%define modsec_version		2.8.0



Name:  		        nginx
Version:        	1.7.5
Release:        	12.1
Summary:        	Robust, small and high performance http and reverse proxy server - heavy module extended pack incl. a few fixes to make them apply cleanly together. RPM Tag íxhuge from now.

Group:          	System Environment/Daemons   

License:    		BSD
URL:            	http://nginx.net/ 
BuildRoot:      	%{_tmppath}/%{name}-%{version}-root

BuildRequires:		pcre-devel zlib-devel perl(ExtUtils::Embed) openssl-devel
BuildRequires:		GeoIP-devel libaio-devel pam-devel

# Modsec
BuildRequires:   	httpd-devel lua-devel curl-devel
BuildRequires:      	libxslt-devel,GeoIP-devel,gd-devel

BuildRequires: 		libxml2-devel


Requires: 	        pcre zlib openssl pam apr-util apr
Requires:       	perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires(pre): 		shadow-utils
Requires(post):     	chkconfig
Requires(preun):    	chkconfig initscripts
Requires(postun):   	initscripts

Provides:   	webserver

Source0:    	http://sysoev.ru/nginx/nginx-%{version}.tar.gz

Source1:    	%{name}.init
Source2:    	%{name}.logrotate
Source3:    	virtual.conf
Source4:    	ssl.conf
Source5:    	nginx-upstream-fair.tgz
Source6:    	upstream-fair.conf
Source7:    	%{name}.sysconfig
Source8:    	ngx_slowfs_cache-1.5.tar.gz
Source9:    	Nginx-limit-traffic-rate-module.tar.gz
Source10:   	proxy.conf
Source11:   	nginx_upstream_check_module-master.tar.gz
Source13:   	nginx-upstream-carp-read-only.tar.gz
Source14: 	%{rtmp}.tar.gz
Source16:       mod_zip-master.tar.gz
Source17:       nginx-upload-progress-module-0.9.0.zip
Source18:       ngx_http_auth_pam_module-1.2.tar.gz
Source20:	GeoIPCountryWhois.csv
Source21:	nginx-http-rdns.tar.gz
Source22:	openssl-%{openssl_version}.tar.gz
		
Source100:  	index.html
Source101:  	poweredby.png
Source102:  	nginx-logo.png
Source103:  	50x.html
Source104:  	404.html
Source105:	nginx-boilerplate.tar.gz
Source107:  	ngx_cache_purge-2.1.tar.gz
Source108:  	modsecurity-%{modsec_version}.tar.gz


# removes -Werror in upstream build scripts.  -Werror conflicts with
# -D_FORTIFY_SOURCE=2 causing warnings to turn into errors.
Patch0:    	nginx-auto-cc-gcc.patch

# configuration patch to match all the Fedora paths for logs, pid files
# etc.
Patch1:     	nginx-conf-0.7.x.patch
Patch2:	    	check_1.2.6+.patch

%description
Nginx [engine x] is an HTTP(S) server, HTTP(S) reverse proxy and IMAP/POP3
proxy server written by Igor Sysoev.

Following third party modules added:
* nginx-upstream-fair
* mod_zip
* ngx_http_auth_pam_module
* nginx-upload-progress-module
* nginx-upload-module
* nginx-rtmp-module
* nginx-upstream-check
* nginx-tcp-proxy
* nginx-slowfs-cache
* nginx-limit-traffic-rate
* nginx-upstream-carp-read-only
* nginx mod security

last but not least this package includes its own openssl 


%prep
%setup -q


%setup -T -D -a 107 -a 108 

%patch0 -p0
%patch1 -p0
%patch2 -p1

%{__tar} zxvf %{SOURCE5}
%{__tar} zxvf %{SOURCE9}
%{__tar} zxvf %{SOURCE11}
#%{__tar} zxvf %{SOURCE12}
%{__tar} zxvf %{SOURCE13}
%{__tar} zxvf %{SOURCE14}
%{__tar} zxvf  %{SOURCE16}
unzip %{SOURCE17}
%{__tar} zxvf %{SOURCE18}
%{__tar} zxvf %{SOURCE22}  


%build

pushd modsecurity-2.8.0
# build mod_security library first
%configure \
%if 0%{?el5}
        --with-libxml=/var/mod_security/usr/ \
%endif
        --enable-standalone-module 
make || :
cd standalone
make install-exec-hook || :
popd



export DESTDIR=%{buildroot}
./configure \
    --user=%{nginx_user} \
    --group=%{nginx_group} \
    --prefix=%{nginx_datadir} \
    --sbin-path=%{_sbindir}/%{name} \
    --conf-path=%{nginx_confdir}/%{name}.conf \
    --error-log-path=%{nginx_logdir}/error.log \
    --http-log-path=%{nginx_logdir}/access.log \
    --http-client-body-temp-path=%{nginx_home_tmp}/client_body \
    --http-proxy-temp-path=%{nginx_home_tmp}/proxy \
    --http-fastcgi-temp-path=%{nginx_home_tmp}/fastcgi \
    --pid-path=%{_localstatedir}/run/%{name}.pid \
    --lock-path=%{_localstatedir}/lock/subsys/%{name} \
    --with-http_secure_link_module \
    --with-http_random_index_module \
    --with-http_ssl_module \
    --with-http_realip_module \
    --with-http_addition_module \
    --with-http_sub_module \
    --with-http_dav_module \
    --with-http_flv_module \
    --with-http_gzip_static_module \
    --with-http_degradation_module \
    --with-http_stub_status_module \
    --with-http_mp4_module  \
    --with-http_geoip_module \
    --with-debug \
    --with-ipv6 \
    --with-http_spdy_module \
    --with-openssl=%{_builddir}/nginx-%{version}/openssl-%{openssl_version} \
    --add-module=%{_builddir}/nginx-%{version}/modsecurity-%{modsec_version}/nginx/modsecurity \
    --add-module=%{_builddir}/nginx-%{version}/ngx_cache_purge-2.1 \
    --add-module=%{_builddir}/nginx-%{version}/nginx-upstream-fair \
    --add-module=%{_builddir}/nginx-%{version}/nginx_upstream_check_module-master \
    --add-module=%{_builddir}/nginx-%{version}/%{rtmp} \
    --add-module=%{_builddir}/nginx-%{version}/Nginx-limit-traffic-rate-module \
    --add-module=%{_builddir}/nginx-%{version}/nginx-upload-progress-module-master \
    --add-module=%{_builddir}/nginx-%{version}/mod_zip-master \
    --add-module=%{_builddir}/nginx-%{version}/ngx_http_auth_pam_module-1.2 \
    --with-cc-opt="%{optflags} $(pcre-config --cflags)" \
    --with-ld-opt="-Wl,--as-needed -Wl,--strip-all" \
    --with-pcre \
    --with-pcre-jit \
    --with-file-aio

make %{?_smp_mflags} 


mv nginx-upstream-fair/README nginx-upstream-fair/README.nginx_upstream_fair

mv mod_zip-master/CHANGES mod_zip-master/CHANGES.mod_zip
mv mod_zip-master/README.markdown mod_zip-master/README.mod_zip
mv mod_zip-master/t/nginx.conf mod_zip-master/t/nginx.conf.mod_zip

mv nginx-upload-progress-module-master/CHANGES nginx-upload-progress-module-master/CHANGES.nginx_upload_progress
mv nginx-upload-progress-module-master/README nginx-upload-progress-module-master/README.nginx_upload_progress

mv ngx_http_auth_pam_module-1.2/ChangeLog ngx_http_auth_pam_module-1.2/ChangeLog.ngx_http_auth_pam_module-1.2
mv ngx_http_auth_pam_module-1.2/README ngx_http_auth_pam_module-1.2/README.ngx_http_auth_pam_module-1.2




%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALLDIRS=vendor
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -type f -empty -exec rm -f {} \;
find %{buildroot} -type f -exec chmod 0644 {} \;
find %{buildroot} -type f -name '*.so' -exec chmod 0755 {} \;
mkdir -p %{buildroot}%{_docdir}/nginx
chmod 0755 %{buildroot}%{_sbindir}/nginx
%{__install} -p -D -m 0755 %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%{__install} -p -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
%{__install} -p -D -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_confdir}/conf.d
%{__install} -p -m 0644 %{SOURCE3} %{SOURCE4} %{SOURCE6} %{SOURCE10} %{buildroot}%{nginx_confdir}/conf.d
%{__install} -p -d -m 0755 %{buildroot}%{nginx_home_tmp}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_logdir}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_webroot}
%{__install} -p -m 0644 %{SOURCE100} %{SOURCE101} %{SOURCE102} %{SOURCE103} %{SOURCE104} %{buildroot}%{nginx_webroot}
%{__install} -p -m 0755 %{SOURCE105} %{buildroot}%{nginx_confdir}/

%{__install} -p -D -m 0755 %{SOURCE13} %{buildroot}%{_bindir}/nginx-upgrade
%{__install} -p -D -m 0755 %{SOURCE14} %{buildroot}%{_mandir}/man8/nginx-upgrade.8

mv ngx_cache_purge-2.1/CHANGES ngx_cache_purge-2.1/CHANGES.ngx_cache_purge
mv ngx_cache_purge-2.1/README.md ngx_cache_purge-2.1/README.ngx_cache_purge
mv ngx_cache_purge-2.1/LICENSE ngx_cache_purge-2.1/LICENSE.ngx_cache_purge
 


# convert to UTF-8 all files that give warnings.
for textfile in CHANGES
do
    mv $textfile $textfile.old
    iconv --from-code ISO8859-1 --to-code UTF-8 --output $textfile $textfile.old
    rm -f $textfile.old
done

%clean
rm -rf %{buildroot}

%pre
%{_sbindir}/useradd -c "Nginx user" -s /bin/false -r -d %{nginx_home} %{nginx_user} 2>/dev/null || :

%post
/sbin/chkconfig --add %{name}

%preun
if [ $1 = 0 ]; then
    /sbin/service %{name} stop >/dev/null 2>&1
    /sbin/chkconfig --del %{name}
fi

%postun
if [ $1 -ge 1 ]; then
    /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi

%files
%defattr(-,root,root,-)
%doc LICENSE CHANGES README 

%doc nginx-upstream-fair/README.nginx_upstream_fair
%doc mod_zip-master/CHANGES.mod_zip mod_zip-master/README.mod_zip mod_zip-master/t/nginx.conf.mod_zip
%doc ngx_http_auth_pam_module-1.2/ChangeLog.ngx_http_auth_pam_module-1.2 ngx_http_auth_pam_module-1.2/README.ngx_http_auth_pam_module-1.2
%doc LICENSE CHANGES README ngx_cache_purge-2.1/CHANGES.ngx_cache_purge ngx_cache_purge-2.1/README.ngx_cache_purge ngx_cache_purge-2.1/LICENSE.ngx_cache_purge

%{_mandir}/man8/nginx-upgrade.8*
#%{_mandir}/man3/*

%{nginx_datadir}/
%{_bindir}/%{name}-upgrade
%{_sbindir}/%{name}
%{_initrddir}/%{name}
%dir %{nginx_confdir}
%dir %{nginx_confdir}/conf.d
%config(noreplace) %{nginx_confdir}/conf.d/*.conf
%config(noreplace) %{nginx_confdir}/win-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf.default
%config(noreplace) %{nginx_confdir}/mime.types.default
%config(noreplace) %{nginx_confdir}/fastcgi_params
%config(noreplace) %{nginx_confdir}/fastcgi_params.default
%config(noreplace) %{nginx_confdir}/fastcgi.conf
%config(noreplace) %{nginx_confdir}/fastcgi.conf.default
%config(noreplace) %{nginx_confdir}/scgi_params
%config(noreplace) %{nginx_confdir}/scgi_params.default
%config(noreplace) %{nginx_confdir}/uwsgi_params           
%config(noreplace) %{nginx_confdir}/uwsgi_params.default
%config(noreplace) %{nginx_confdir}/koi-win
%config(noreplace) %{nginx_confdir}/koi-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf
%config(noreplace) %{nginx_confdir}/mime.types
%config %{nginx_confdir}/nginx-boilerplate.tar.gz
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home_tmp}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_logdir}


%changelog
* Thu Sep 25 2014 Juergen Gotteswinter <jg@internetx.com> - 1.7.5-ixuber1
- 1.7.5 bump
- patch cleanup
- fixed segfaults caused by bogus patch
- added nginx boilerplate - check doc directory

* Fri Jul 11 2014 Juergen Gotteswinter <jg@internetx.de> - 1.7.3-ixuber1
- 1.7.3 rebuild

* Mon Jun 23 2014 Juergen Gotteswinter <jg@internetx.de> - 1.7.2-ixuber1
- version bump to 1.7.2
- added nginx-upgrade script for flawless nginx upgrades

* Mon Jun 16 2014 Juergen Gotteswinter <jg@internetx.de> - 1.7.1-ixevenbigger
- bumped to 1.7.1
- included its own openssl source tarball where the nginx got built against static

* Fri Apr 26 2014 Juergen Gotteswinter <jg@internetx.de> - 1.7.0-ixhuge1
- version bump to 1.7.0

* Thu Apr 03 2014 Juergen Gotteswinter <jg@internetx.de> - 1.5.10-ixhuge3
- updated to 1.5.12

* Sun Feb 18 2014 Juergen Gotteswinter <jg@internetx.de> - 1.5.10-ixhuge3
- added nginx mod_pagespeed
- added nginx mod_security
- added nginx cache_purge

* Sun Jan 19 2014 Juergen Gotteswinter <jg@internetx.de> - 1.5.8-ixhuge2
* added nginx-http-rdns module

* Wed Jan 07 2014 Juergen Gotteswinter <jg@internetx.de> - 1.5.8-1
- version bump to 1.5.8 latest mainline
- changed releasetag to clearify the presence of spdy3 patch
- added proxy protocol patch to play well together with haproxy


* Wed Dec 07 2013 Juergen Gotteswinter <jg@internetx.de> - 1.5.7-2
- added nginx tcp proxy module

* Wed Nov 20 2013 Juergen Gotteswinter <jg@internetx.de> - 1.5.7-1
- https://bugzilla.redhat.com/show_bug.cgi?id=1032266

* Tue Oct 08 2013 Carsten Schoene <cs@linux-administrator.com> - 1.4.3-1
- update nginx to 1.4.3
- update rtmp module to 1.0.5

* Sun Aug 04 2013 Carsten Schoene <cs@linux-administrator.com> - 1.4.2-2
- update rtmp module to 1.0.2

* Wed Jul 17 2013 Carsten Schoene <cs@linux-administrator.com> - 1.4.2-1
- update nginx to 1.4.2

* Sat Jun 29 2013 Carsten Schoene <cs@linux-administrator.com> - 1.4.1-4
- update rtmp module to 1.0.1

* Sat May 25 2013 Carsten Schoene <cs@linux-administrator.com> - 1.4.1-3
- update rtmp module to 0.9.20

* Mon May 13 2013 Carsten Schoene <cs@linux-administrator.com> - 1.4.1-2
- update rtmp module to 0.9.19

* Fri May 10 2013 Juergen Gotteswinter <jg@internetx.de> - 1.4.1-1
- version bump to latest stable 1.4.1

* Fri Apr 26 2013 Carsten Schoene <cs@linux-administrator.com> - 1.2.7-2
- update rtmp module to 0.9.18

* Sun Apr 14 2013 Carsten Schoene <cs@linux-administrator.com> - 1.2.7-4
- update nginx to 1.2.7
- update rtmp module to 0.9.14

* Mon Mar 04 2013 Carsten Schoene <cs@linux-administrator.com> - 1.2.7-3
- update rtmp module to 0.9.11

* Thu Feb 28 2013 Carsten Schoene <cs@linux-administrator.com> - 1.2.7-2
- update rtmp module to 0.9.8

* Tue Feb 12 2013 Carsten Schoene <cs@linux-administrator.com> - 1.2.7-1
- update nginx to 1.2.7
- update rtmp module to 0.9.7

* Fri Jan 25 2013 Carsten Schoene <cs@linux-administrator.com> - 1.2.6-4
- update rtmp module to 0.9.1

* Wed Jan 16 2013 Carsten Schoene <cs@linux-administrator.com> - 1.2.6-3
- update rtmp module to 0.9.0

* Sat Jan 12 2013 Carsten Schoene <cs@linux-administrator.com> - 1.2.6-2
- added rtmp 0.8.7 module

* Tue Dec 11 2012 Carsten Schoene <cs@linux-administrator.com> - 1.2.6-1
- update to release 1.2.6

* Tue Nov 13 2012 Carsten Schoene <cs@linux-administrator.com> - 1.2.5-1
- update to release 1.2.5

* Mon Oct 04 2010 Juergen Gotteswinter <jg at internetx.de> 0.8.52-1
- update to latest stable branch

* Wed Nov 17 2009 Juergen Gotteswinter <jg at internetx.de> 0.7.64-1

- version bump to 0.7.64


* Wed Oct 28 2009 Juergen Gotteswinter <jg at internetx.de> 0.7.63-1

- version bump to 0.7.63

* Fri Oct 23 2009 Juergen Gotteswinter <jg at internetx.de> 0.7.62-3
- included nginx-socket-patch for unix socket support
